#!/usr/bin/env python

"""
General support for calendar data storage.

Copyright (C) 2016, 2017 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.stores.manifest import stores

# Access functions.

def get_store(store_type, store_dir):

    """
    Return a store for the given 'store_type' and 'store_dir'. If 'store_dir'
    is given as a null or false value then the configured default is used.
    """

    return stores[store_type].Store(store_dir)

def get_publisher(publishing_dir):

    """
    Return a publishing resource employing 'publishing_dir'. If the specified
    directory is given as a null or false value, None is returned. Thus, all
    free/busy publishing can be disabled by changing the configuration to use
    None as the directory.
    """

    return publishing_dir and stores["file"].Publisher(publishing_dir) or None

def get_journal(store_type, journal_dir):

    """
    Return a journal for the given 'store_type' and 'journal_dir'. If
    'journal_dir' is given as a null or false value then the configured default
    is used.
    """

    return stores[store_type].Journal(journal_dir)

# vim: tabstop=4 expandtab shiftwidth=4
